@@ -1,13 +1,13 @@
 """Command-line implementation of flake8_nb."""
+from __future__ import annotations
+
 import sys
-from typing import List
-from typing import Optional
 
 from flake8_nb import FLAKE8_VERSION_TUPLE
 from flake8_nb.flake8_integration.cli import Flake8NbApplication
 
 
-def main(argv: Optional[List[str]] = None) -> None:
+def main(argv: list[str] | None = None) -> None:
     """Execute the main bit of the application.
 
     This handles the creation of an instance of :class:`Application`, runs it,
@@ -16,18 +16,11 @@ def main(argv: Optional[List[str]] = None) -> None:
 
     Parameters
     ----------
-    argv: List[str], optional
+    argv: list[str] | None
         The arguments to be passed to the application for parsing.
     """
-    # TODO: remove compat after flake8>3.8.0 release
-    # tested with flake8-nightly, in test__main__.py,
-    # but not picked up by by coverage
-    if FLAKE8_VERSION_TUPLE > (3, 7, 9):  # pragma: no cover
-        if argv is None:
-            argv = sys.argv[1:]
-        else:
-            argv = argv[1:]
-
+    if FLAKE8_VERSION_TUPLE > (3, 7, 9):
+        argv = sys.argv[1:] if argv is None else argv[1:]
     app = Flake8NbApplication()
     app.run(argv)
     app.exit()
